#!/usr/bin/env python3

# SPDX-FileCopyrightText: © 2022 Decompollaborate
# SPDX-License-Identifier: MIT

from __future__ import annotations


from .DisasmdisInternals import getArgsParser, applyArgs, getInstrCategoryFromStr, getWordListFromStrList, disasmdisMain
